==> duckplyr_1.1.2.tar.gz: duckplyr/R/dplyr.R <==
dplyr <- asNamespace("dplyr")

across_glue_mask <- dplyr$across_glue_mask
as_across_fn_call <- dplyr$as_across_fn_call
as_group_map_function <- dplyr$as_group_map_function
as_fun_list <- dplyr$as_fun_list
as_join_by <- dplyr$as_join_by
check_filter <- dplyr$check_filter
check_keep <- dplyr$check_keep
check_name <- dplyr$check_name
check_n_name <- dplyr$check_n_name
check_na_matches <- dplyr$check_na_matches
check_string <- dplyr$check_string
check_transmute_args <- dplyr$check_transmute_args
compute_by <- dplyr$compute_by
context_poke <- dplyr$context_poke
count_regroups <- dplyr$count_regroups
cur_column <- dplyr$cur_column
DataMask <- dplyr$DataMask
dplyr_error_call <- dplyr$dplyr_error_call
dplyr_local_error_call <- dplyr$dplyr_local_error_call
dplyr_quosures <- dplyr$dplyr_quosures
eval_relocate <- dplyr$eval_relocate
eval_select_by <- dplyr$eval_select_by
expand_across <- dplyr$expand_across
expand_if_across <- dplyr$expand_if_across
expr_substitute <- dplyr$expr_substitute
get_slice_size <- dplyr$get_slice_size
group_by_drop_default <- dplyr$group_by_drop_default
group_keys0 <- dplyr$group_keys0
is_cross_by <- dplyr$is_cross_by
join_by_common <- dplyr$join_by_common
join_cols <- dplyr$join_cols
# Need to reimplement mutate_keep() to avoid dplyr_col_select()
# mutate_keep <- dplyr$mutate_keep
mutate_relocate <- dplyr$mutate_relocate
new_dplyr_quosure <- dplyr$new_dplyr_quosure
new_join_by <- dplyr$new_join_by
quo_eval_fns <- dplyr$quo_eval_fns
sample_int <- dplyr$sample_int
some <- dplyr$some
tally_n <- dplyr$tally_n

# Only for dead legacy code?
add_count_impl <- dplyr$add_count_impl
arrange_rows <- dplyr$arrange_rows
check_frac <- dplyr$check_frac
check_size <- dplyr$check_size
coalesce <- dplyr$coalesce
commas <- dplyr$commas
compact_null <- dplyr$compact_null
distinct_prepare <- dplyr$distinct_prepare
dplyr_col_select <- dplyr$dplyr_col_select
dplyr_local_slice_by_arg <- dplyr$dplyr_local_slice_by_arg
dplyr_new_list <- dplyr$dplyr_new_list
ensure_group_vars <- dplyr$ensure_group_vars
env_bind_do_pronouns <- dplyr$env_bind_do_pronouns
filter_rows <- dplyr$filter_rows
groups <- dplyr$groups
group_nest_impl <- dplyr$group_nest_impl
group_split_impl <- dplyr$group_split_impl
join_cast_common <- dplyr$join_cast_common
join_filter <- dplyr$join_filter
join_mutate <- dplyr$join_mutate
join_rows <- dplyr$join_rows
mutate_cols <- dplyr$mutate_cols
mutate_keep <- dplyr$mutate_keep
named_args <- dplyr$named_args
rethrow_error_join_incompatible_type <- dplyr$rethrow_error_join_incompatible_type
rows_bind <- dplyr$rows_bind
rows_cast_y <- dplyr$rows_cast_y
rows_check_by <- dplyr$rows_check_by
rows_check_contains_by <- dplyr$rows_check_contains_by
rows_check_unique <- dplyr$rows_check_unique
rows_check_x_contains_y <- dplyr$rows_check_x_contains_y
rows_check_y_conflict <- dplyr$rows_check_y_conflict
rows_check_y_unmatched <- dplyr$rows_check_y_unmatched
rows_df_in_place <- dplyr$rows_df_in_place
rowwise_df <- dplyr$rowwise_df
slice_rows <- dplyr$slice_rows
summarise_build <- dplyr$summarise_build
summarise_cols <- dplyr$summarise_cols
summarise_deprecate_variable_size <- dplyr$summarise_deprecate_variable_size
the <- dplyr$the
tick_if_needed <- dplyr$tick_if_needed
warn_join_cross_by <- dplyr$warn_join_cross_by

==> duckplyr_1.2.0.tar.gz: duckplyr/R/dplyr.R <==
dplyr <- asNamespace("dplyr")

across_glue_mask <- dplyr$across_glue_mask
as_across_fn_call <- dplyr$as_across_fn_call
as_group_map_function <- dplyr$as_group_map_function
as_fun_list <- dplyr$as_fun_list
as_join_by <- dplyr$as_join_by
check_filter <- dplyr$check_filter
check_keep <- dplyr$check_keep
check_name <- dplyr$check_name
check_n_name <- dplyr$check_n_name
check_na_matches <- dplyr$check_na_matches
check_string <- dplyr$check_string
check_transmute_args <- dplyr$check_transmute_args
compute_by <- dplyr$compute_by
context_poke <- dplyr$context_poke
count_regroups <- dplyr$count_regroups
cur_column <- dplyr$cur_column
DataMask <- dplyr$DataMask
dplyr_error_call <- dplyr$dplyr_error_call
dplyr_local_error_call <- dplyr$dplyr_local_error_call
dplyr_quosures <- dplyr$dplyr_quosures
eval_relocate <- dplyr$eval_relocate
eval_select_by <- dplyr$eval_select_by
expand_across <- dplyr$expand_across
expand_if_across <- dplyr$expand_if_across
expr_substitute <- dplyr$expr_substitute
get_slice_size <- dplyr$get_slice_size
group_by_drop_default <- dplyr$group_by_drop_default
group_keys0 <- dplyr$group_keys0
is_cross_by <- dplyr$is_cross_by
join_by_common <- dplyr$join_by_common
join_cols <- dplyr$join_cols
# Need to reimplement mutate_keep() to avoid dplyr_col_select()
# mutate_keep <- dplyr$mutate_keep
mutate_relocate <- dplyr$mutate_relocate
new_dplyr_quosure <- dplyr$new_dplyr_quosure
new_join_by <- dplyr$new_join_by
quo_eval_fns <- dplyr$quo_eval_fns
sample_int <- dplyr$sample_int
some <- dplyr$some
tally_n <- dplyr$tally_n
vec_case_match <- dplyr$vec_case_match
replace_when <- dplyr$replace_when

# Only for dead legacy code?
add_count_impl <- dplyr$add_count_impl
arrange_rows <- dplyr$arrange_rows
check_frac <- dplyr$check_frac
check_size <- dplyr$check_size
commas <- dplyr$commas
compact_null <- dplyr$compact_null
compat_wt <- dplyr$compat_wt
distinct_prepare <- dplyr$distinct_prepare
dplyr_col_select <- dplyr$dplyr_col_select
dplyr_local_slice_by_arg <- dplyr$dplyr_local_slice_by_arg
dplyr_new_list <- dplyr$dplyr_new_list
ensure_group_vars <- dplyr$ensure_group_vars
env_bind_do_pronouns <- dplyr$env_bind_do_pronouns
filter_impl <- dplyr$filter_impl
filter_rows <- dplyr$filter_rows
groups <- dplyr$groups
group_nest_impl <- dplyr$group_nest_impl
group_split_impl <- dplyr$group_split_impl
join_cast_common <- dplyr$join_cast_common
join_filter <- dplyr$join_filter
join_mutate <- dplyr$join_mutate
join_rows <- dplyr$join_rows
mutate_cols <- dplyr$mutate_cols
mutate_keep <- dplyr$mutate_keep
named_args <- dplyr$named_args
rethrow_error_join_incompatible_type <- dplyr$rethrow_error_join_incompatible_type
rows_bind <- dplyr$rows_bind
rows_cast_y <- dplyr$rows_cast_y
rows_check_by <- dplyr$rows_check_by
rows_check_contains_by <- dplyr$rows_check_contains_by
rows_check_unique <- dplyr$rows_check_unique
rows_check_x_contains_y <- dplyr$rows_check_x_contains_y
rows_check_y_conflict <- dplyr$rows_check_y_conflict
rows_check_y_unmatched <- dplyr$rows_check_y_unmatched
rows_df_in_place <- dplyr$rows_df_in_place
rowwise_df <- dplyr$rowwise_df
slice_rows <- dplyr$slice_rows
summarise_build <- dplyr$summarise_build
summarise_cols <- dplyr$summarise_cols
the <- dplyr$the
tick_if_needed <- dplyr$tick_if_needed
warn_join_cross_by <- dplyr$warn_join_cross_by
